==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_hac.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=hac
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_modere_abonnement' => 'تۊمارکەردەی وازیان',

	// E
	'extensions_autorisees_toutes' => 'گرد',

	// F
	'form_pet_message_commentaire' => 'يك پيام ، يك تفسير ؟',
	'forum' => 'فۆڕوم',
	'forum_acces_refuse' => '.شما ديگر اجازه استفاده از اين سخنگاه را نداريد',
	'forum_attention_dix_caracteres' => '</b>! توجه<b>   پيامتان بايد بيش از ده حرف باشد.',
	'forum_attention_trois_caracteres' => '</b>! توجه<b> عنوانتان بايد بيش از سه حرف باشد. ',
	'forum_attention_trop_caracteres' => '<b>توجه!</b> پیامتان بسیار طولانی است     (@compte@کلمه)  و نباید از  @max@ کلمه بیشتر باشد.', # MODIF
	'forum_avez_selectionne' => ': شما انتخاب كرده ايد',
	'forum_cliquer_retour' => ' </a> اينجا <a href=\'@retour_forum@\'>     را براى ادامه كليك كنيد     ',
	'forum_forum' => 'سخنگاه',
	'forum_info_modere' => 'سخنگاه : پيامهاى شما پس از تأئيد گردانند گان سايت نمايان خواهند شد', # MODIF
	'forum_lien_hyper' => ' (اختيارى)  </b>پيوند هايپرتكست<b> ', # MODIF
	'forum_message_definitif' => 'پيام نهايى : به سايت بفرستيد',
	'forum_message_trop_long' => 'پيامتان بيش از حد بلند است. حداكثر اندازه ٢٠٠٠٠ حرف است', # MODIF
	'forum_ne_repondez_pas' => 'به اين ايميل پاسخ ندهيد،  پاسختان را در سخنگاه به آدرس زير بفرستيد',
	'forum_page_url' => 'اگر پيامتان راجع به يك مقاله چاپ شده يا به يك صفحه اى كه داراى اطلاعات سودمندى است مربوط ميشود، خواهشمند است عنوان صفحه وآدرس آنرا در زير مشخص كنيد ',
	'forum_poste_par' => 'پيام @parauteur@ بدنبال مقاله « @titre@ »  فرستاده شده. ', # MODIF
	'forum_qui_etes_vous' => '(اختيارى) <b> كى هستيد؟ </b>                                      ', # MODIF
	'forum_texte' => 'تێکستو پەیامەکەو تۊ',
	'forum_titre' => 'سەردېڕ',
	'forum_url' => 'لینک',
	'forum_valider' => 'اين انتخاب را معتبر كنيد',
	'forum_voir_avant' => 'اين پيام را پيش از فرستادن آن بخوانيد', # MODIF
	'forum_votre_email' => 'ئیمەیل ئەدرەسو تۊ',
	'forum_votre_nom' => 'نامۊ تۊ',
	'forum_vous_enregistrer' => ' براى شركت در اين سخنگاه، شما بايد از پيش ثبت نام ميكرديد. خواهشمند است كلمه شناساييتان را كه دريافت كرده ايد در زير مشخص كنيد.اگر ثبت نشديد، بايد',
	'forum_vous_inscrire' => 'ثبت نام كنيد.   ',

	// I
	'icone_suivi_forums' => 'پيگيرى/اداره كردن سخنگاه',
	'icone_supprimer_message' => 'اين پيام را حذف كنيد',
	'icone_valider_message' => 'اين پيام را معتبر كنيد',
	'info_liens_syndiques_3' => 'سەکۊکۍ',
	'info_liens_syndiques_4' => 'ھەنۍ',
	'info_liens_syndiques_6' => 'ھەن',
	'info_pas_de_forum' => 'سەکۊ نیا',

	// M
	'messages_aucun' => 'ھیچ',
	'messages_tous' => 'گرد',

	// O
	'onglet_messages_internes' => 'پيام هاى داخلى',
	'onglet_messages_publics' => 'پيام هاى همگانى',
	'onglet_messages_vide' => 'پيام هاى بدون متن',

	// T
	'titre_forum' => 'فوروم'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_hac.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=hac
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_modere_abonnement' => 'تۊمارکەردەی وازیان',

	// E
	'extensions_autorisees_toutes' => 'گرد',

	// F
	'form_pet_message_commentaire' => 'يك پيام ، يك تفسير ؟',
	'forum' => 'فۆڕوم',
	'forum_acces_refuse' => '.شما ديگر اجازه استفاده از اين سخنگاه را نداريد',
	'forum_attention_dix_caracteres' => '</b>! توجه<b>   پيامتان بايد بيش از ده حرف باشد.',
	'forum_attention_trois_caracteres' => '</b>! توجه<b> عنوانتان بايد بيش از سه حرف باشد. ',
	'forum_attention_trop_caracteres' => '<b>توجه!</b> پیامتان بسیار طولانی است     (@compte@کلمه)  و نباید از  @max@ کلمه بیشتر باشد.', # MODIF
	'forum_avez_selectionne' => ': شما انتخاب كرده ايد',
	'forum_cliquer_retour' => ' </a> اينجا <a href=\'@retour_forum@\'>     را براى ادامه كليك كنيد     ',
	'forum_forum' => 'سخنگاه',
	'forum_info_modere' => 'سخنگاه : پيامهاى شما پس از تأئيد گردانند گان سايت نمايان خواهند شد', # MODIF
	'forum_lien_hyper' => ' (اختيارى)  </b>پيوند هايپرتكست<b> ', # MODIF
	'forum_message_definitif' => 'پيام نهايى : به سايت بفرستيد',
	'forum_message_trop_long' => 'پيامتان بيش از حد بلند است. حداكثر اندازه ٢٠٠٠٠ حرف است', # MODIF
	'forum_ne_repondez_pas' => 'به اين ايميل پاسخ ندهيد،  پاسختان را در سخنگاه به آدرس زير بفرستيد',
	'forum_page_url' => 'اگر پيامتان راجع به يك مقاله چاپ شده يا به يك صفحه اى كه داراى اطلاعات سودمندى است مربوط ميشود، خواهشمند است عنوان صفحه وآدرس آنرا در زير مشخص كنيد ',
	'forum_poste_par' => 'پيام @parauteur@ بدنبال مقاله « @titre@ »  فرستاده شده. ', # MODIF
	'forum_qui_etes_vous' => '(اختيارى) <b> كى هستيد؟ </b>                                      ', # MODIF
	'forum_texte' => 'تێکستو پەیامەکەو تۊ',
	'forum_titre' => 'سەردېڕ',
	'forum_url' => 'لینک',
	'forum_valider' => 'اين انتخاب را معتبر كنيد',
	'forum_voir_avant' => 'اين پيام را پيش از فرستادن آن بخوانيد', # MODIF
	'forum_votre_email' => 'ئیمەیل ئەدرەسو تۊ',
	'forum_votre_nom' => 'نامۊ تۊ',
	'forum_vous_enregistrer' => ' براى شركت در اين سخنگاه، شما بايد از پيش ثبت نام ميكرديد. خواهشمند است كلمه شناساييتان را كه دريافت كرده ايد در زير مشخص كنيد.اگر ثبت نشديد، بايد',
	'forum_vous_inscrire' => 'ثبت نام كنيد.   ',

	// I
	'icone_suivi_forums' => 'پيگيرى/اداره كردن سخنگاه',
	'icone_supprimer_message' => 'اين پيام را حذف كنيد',
	'icone_valider_message' => 'اين پيام را معتبر كنيد',
	'info_liens_syndiques_3' => 'سەکۊکۍ',
	'info_liens_syndiques_4' => 'ھەنۍ',
	'info_liens_syndiques_6' => 'ھەن',
	'info_pas_de_forum' => 'سەکۊ نیا',

	// M
	'messages_aucun' => 'ھیچ',
	'messages_tous' => 'گرد',

	// O
	'onglet_messages_internes' => 'پيام هاى داخلى',
	'onglet_messages_publics' => 'پيام هاى همگانى',
	'onglet_messages_vide' => 'پيام هاى بدون متن',

	// T
	'titre_forum' => 'فوروم',
];
